#
# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Mac.tcl,v $
# $Date: 1998/02/09 16:56:41 $
# $Revision: 1.18.1.7 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
#
package provide macintosh 1.18
#
proc tmpdir {} {
    global env zircon
    if {[info exists zircon(tmp)]} { return $zircon(tmp) }
    if {[info exists env(TEMP)]} { return $env(TEMP) }
    set fl [file join $env(PREF_FOLDER) Zircon temp]
    if {![file exists $fl]} { file mkdir $fl }
    return $fl
}
#
proc prefdir {} {global env ; return [file join $env(PREF_FOLDER) Zircon]}
#
proc username {} { global env ; return $env(USER) }
#
# No DCC on the Mac at the moment.
#
proc dccCheck {args} {}
#
proc net_dccClean {args} {}
